小偷家族 (豆瓣)
Description: 小偷家族电影简介和剧情介绍,小偷家族影评、图片、预告片、影讯、论坛、在线购票
Keywords: 小偷家族,万引き家族,小偷家族影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.183豆瓣电影Top250

# 小偷家族 万引き家族 (2018)

导演: 是枝裕和
编剧: 是枝裕和
主演: 中川雅也 / 安藤樱 / 松冈茉优 / 城桧吏 / 佐佐木美结 / 树木希林 / 绪形直人 / 池松壮亮 / 森口瑶子 / 山田裕贵 / 片山萌美 / 柄本明 / 高良健吾 / 池胁千鹤 / 足立智充
类型: 剧情 / 家庭 / 犯罪
官方网站: gaga.ne.jp/manbiki-kazoku/
制片国家/地区: 日本
语言: 日语
上映日期: 2018-08-03(中国大陆) / 2018-05-13(戛纳电影节) / 2018-06-08(日本)
片长: 117分钟(中国大陆) / 121分钟
又名: Shoplifters / Une Affaire de Famille / Manbiki kazoku
IMDb: tt8075192
豆瓣评分
引用
8.7
779275人评价
5星
45.0%
4星
44.7%
3星
9.4%
2星
0.7%
1星
0.2%
好于 97% 家庭片
好于 97% 剧情片
想看 看过
评价:
推荐

## 小偷家族的剧情简介 · · · · · ·

东京的都市丛林中央，残存着一栋古旧寒酸的老房子，这里局促地生活着柴田一家五口人。在工地当临时工的男人阿治（Lily Franky 饰）经常带着儿子祥太（城桧吏 饰）到超市盗窃生活用品，这一天，他们回家路上遇到了独自待在户外的四岁女孩由里（佐佐木美结 饰）。妻子信代（安藤樱 饰）起初极力主张将女孩送回父母身边，但当看到女孩原生家庭的状况时又心生恻隐。原本柴田家就靠着老奶奶初枝（树木希林 饰）的养老金度日，而今多了一口人，自然更艰辛了几分。包括信代的妹妹亚纪（松冈茉优 饰）在内，虽然一家人游走在贫困和违法的边缘，但笃深的羁绊将他们紧紧联系在一起，使他们的心不会随着冰冷的都市而寒冷下去……
本片荣获第71届戛纳电影节金棕榈 ©豆瓣

## 小偷家族的演职员 · · · · · · ( 全部 30 )

- 是枝裕和 导演
- 中川雅也 饰 柴田治
- 安藤樱 饰 柴田信代
- 松冈茉优 饰 柴田亚纪 / 纱香
- 城桧吏 饰 柴田祥太
- 佐佐木美结 饰 友里

## 小偷家族的视频和图片 · · · · · · ( 预告片20 | 添加视频评论 | 图片971 · 添加 )

## 小偷家族的获奖情况 · · · · · · ( 全部 )

- 第91届奥斯卡金像奖
- 最佳外语片(提名)
- 是枝裕和

- 第71届戛纳电影节
- 主竞赛单元 金棕榈奖
- 是枝裕和

- 第76届金球奖
- 电影类 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  步履不停

  饮食男女

  如父如子

  海街日记

  比海更深

  82年生的金智英

  海边的曼彻斯特

  婚姻故事

  寻梦环游记

  阳光普照

我要写短评

## 小偷家族的短评 · · · · · · ( 全部 201889 条 )

热门 / 最新 / 好友

### 26734 有用 西楼尘 看过 2018-07-02 17:32:29

最费力的成长留在树上的只有壳，最狰狞的伤口留在皮肤的只有疤。最动人的烟火绽在空中看不到，最深沉的感谢飘进风中听不清。你教我食物最美味的吃法，却教我获得食物最羞耻的手法；我学会祈祷最灵验的手势，也学会用来祈祷最不齿的心愿。我在商店里偷换掉童年，你在泥土里掩埋了伤疤，而我们组成了家。

### 13595 有用 朝暮雪 看过 2018-08-02 10:33:17

或是被第三者插足，或是不受父母待见，或是被辞退，或是父母根本不想把Ta生下来……这群被抛弃的人们，却共同组成了最温馨、最和睦、最融洽、最可爱的家庭。 他们或是失业，或是工伤，或是以偷窃维持生计，或是在风俗店工作，他们生活在社会的最底层，他们缺少物质财富，精神生活却无比充实。 他们每个人之间都没有血缘关系，但每个人都比原来的家庭过得更加快乐。 结婚不意味着幸福，被丈夫抛弃也能子孙满堂； 生了孩子不一... 或是被第三者插足，或是不受父母待见，或是被辞退，或是父母根本不想把Ta生下来……这群被抛弃的人们，却共同组成了最温馨、最和睦、最融洽、最可爱的家庭。 他们或是失业，或是工伤，或是以偷窃维持生计，或是在风俗店工作，他们生活在社会的最底层，他们缺少物质财富，精神生活却无比充实。 他们每个人之间都没有血缘关系，但每个人都比原来的家庭过得更加快乐。 结婚不意味着幸福，被丈夫抛弃也能子孙满堂； 生了孩子不一定就是母亲，没有生育能力也可以给予母爱。 柴田治以为什么都教不了孩子，却教会了他什么叫青春期。 亚纪远离了富有的家庭，因为4号先生的肩膀更让她感到温暖。 由里遭到亲生父母虐待，却有一位素不相识的人愿意以失去工作的代价保护她。 富有富的活法，穷有穷的活法。我们在丰衣足食中颓废度日，他们在贫困交加中感受大爱无疆。 (展开)

### 7000 有用 咯咯精 看过 2018-05-14 19:31:33

如果说爱你，还打你，那一定是说谎；如果爱你，就会像安藤樱一样紧紧抱住你。（沉溺于安藤樱的美色无法自拔

### 7051 有用 OhBoyDaily 看过 2018-08-03 10:17:40

安藤樱那场在警察局双手不停抹眼泪的戏，演技大爆炸，可以说是年度最佳哭戏！

### 6956 有用 姨妈的鸭 看过 2018-06-23 12:34:42

比起放下手机，这本电影在观影时需要观众做的第一步是：放下三观。

> 更多短评 201889条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 小偷家族的影评 · · · · · · ( 全部 4322 条 )

热门 / 最新 / 好友
顿河 2018-05-17 13:58:34

## 善是本能 爱要习得

这篇影评可能有剧透

本文涉及大量剧透. 潦倒的工厂工人柴田治（Osamu）和儿子祥太（Shota）从商店合作偷窃回来，将被生母漠视独自在家的小姑友里（Yuri）捡回了家。治的妻子信代（Nobuyo）本不想收养，得知她受双亲虐待后改变了主意，奶奶初枝和妻妹亚纪（Aki）对此也没有意见，友里很快就接受了自... (展开)
7873 298 283回应 收起
木卫二 2018-08-04 13:06:45 #《小偷家族》中有哪些值得称道的细节之处？

## 108个秘密

六月底，巴黎的朋友，突然发来一条微信，说自己正在居酒屋，看到一个东方面孔的大叔进来，好像是枝裕和。然后，我鼓励她去Say Hi致意，并合影留念。 朋友很喜欢是枝导演的。 静得下来又有人生阅历的影迷，有谁不喜欢他呢。我跟她说了一个理由，略有夸张。我说，这辈子大概很难... (展开)
4597 299 163回应 收起
彩骚戏话 2018-08-06 14:02:23

## 《小偷家族》各成员过往经历&行为动机分析

这篇影评可能有剧透

以成员为单位对本片的剧情做了梳理，对每个角色过去留白的地方进行了一些猜测。 柴田初枝：在没有组成现在的家庭之前，初枝的晚年生活是相当寂寥的。《小偷家族》的小说里提到，初枝确实有一个儿子，和儿子儿媳住在现在的平房里，而儿子和儿媳的名字呢？正是治和信代。真正的治... (展开)
6338 56 197回应 收起
郎真多 2018-08-04 03:19:56 #《小偷家族》中有哪些值得称道的细节之处？

## 不止25个细节：那些无声的羁绊，那些有声的家

这篇影评可能有剧透

本文严重剧透，请一定在看完电影后阅读，感谢！ 周三豆瓣的超前点映场，今天首映再次去看，正如之前所看的是枝裕和监督的电影，第二次看真的不一样了。我刚刚从影院回来，我只想对电影中的细节说说我自己的感受，不是评论，与大家分享。 如果你看过导演之前的电影，你一定会从... (展开)
4449 271 328回应 收起
寒枝雀静 2018-07-03 01:31:00

## 那一晚的烟花是真的吗？

这篇影评可能有剧透

「哑剧」与看不见的烟花 在《燃烧》中，李沧东在影片开头便通过女主之口抛出了「哑剧」的概念。「哑剧」的精髓不在于想象事物的存在，而是忘记其不存在。底层人物物质匮乏与精神生活的联结通过这一概念巧妙地联结一体。 有趣的是，在戛纳同台竞技的《小偷家族》也出现了一个意... (展开)
1647 117 146回应 收起
朝暮雪 2018-08-02 16:58:58 #《小偷家族》里对于家人的定义是如何表现的？与是枝裕和以往的电影有何不同？

## 除了钱，我们什么都有。

这篇影评可能有剧透

是枝裕和是一位大师级导演，他有三部电影进入豆瓣TOP 250。 《无人知晓》9.0分，排名193。 《步履不停》8.8分，排名226。 《海街日记》8.6分，排名233。 除此之外，还有《奇迹》和《比海更深》8.7分，《如父如子》8.4分，《幻之光》8.2分…… 今年的戛纳电影节上，是枝裕和带来... (展开)
1593 108 83回应 收起
死于昨日 2018-08-04 16:02:26 #《小偷家族》有哪些有趣的设定？

## 《小偷家族》有哪些有趣的设定？

这篇影评可能有剧透

五口人永远也不知道，奶奶在海边说的那句谢谢你们。 纱香永远也不会知道，奶奶拿的那笔钱一分也没用。 爸爸永远也不会知道，翔太在公交车上说的那句爸爸。 旁人永远也不知道，一家六口的羁绊与「家人」。 但是我们知道。 而我们也不知道 玲玲到底等没等到，她的「妈妈」 翔太到... (展开)
700 54 87回应 收起
雅君 2018-08-05 13:43:05 #《小偷家族》中有哪些值得称道的细节之处？

## 《小偷家族》中有哪些值得称道的细节之处？

这篇影评可能有剧透

昨天深夜看完《小偷家族》之后，晚上睡前和今早醒来，都在想这部电影，干脆写了一点观后感。 以下文字有明显剧透。 如果你还没有看过这部电影，我非常推荐你去看，并建议你看完电影之后，再来看这篇推送。 当然如果你不介意剧透，想在观片之前了解更多电影里值得留心的细节，那... (展开)
1163 8 62回应 收起
余小岛 2018-08-02 13:50:11 #《小偷家族》里对于家人的定义是如何表现的？与是枝裕和以往的电影有何不同？

## 他们已经足够相爱，为什么还是不能获得幸福？

不知道从什么时候开始，很多国内观众说起是枝裕和总会评价他为“小津接班人”“下一个小津安二郎”。纵使是枝裕和本人不止在一次的采访中，明确地提出他的身上并没有小津的遗传因子，甚至相比于小津而言，侯孝贤对他电影的影响都更大一些，但还是没能改变大多数人固执地持有这... (展开)
528 47 20回应 收起

> 更多影评 4322篇

添加新讨论

## 讨论区 · · · · · ·

我能看懂这个故事所有想要探讨的东西，但是没有办... | 来自alex | 33 回应 | 2022-11-22 14:00:28
冷静点，别吹捧了 | 来自夏夏 | 1115 回应 | 2022-11-19 12:49:54
如果这部片是个国内的导演拍……估计六分都不到吧？ | 来自番茄是橙子味的 | 142 回应 | 2022-11-02 21:06:51
奶奶是不是不知道小姐姐去色情场所工作呢？ | 来自cocojamboo | 19 回应 | 2022-10-23 16:59:25
问一个很傻逼的问题：是不是日本有二胎政策啊 | 来自玖拾玖 | 25 回应 | 2022-10-23 16:52:34

> 去这部影片的讨论区（全部899条）

## 关于《小偷家族》的问题 · · · · · · ( 全部30个 )

- 请问玲玲最后片段什么意思？ 5人回答
- 祥太被抓到医院，“爸爸”和“妈妈”去了医院的做法是硬要急转剧情的生硬bug么？ 3人回答

> 全部30个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 芒果TV VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 日本《电影旬报》年度十佳影片 (木卫二)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 亚洲的好电影 (一一)
- 评价人数超过十万的电影 (依然饭特稀)

## 谁在看这部电影 · · · · · ·

- 豆友ZYW7_fy9t8
  1分钟前 看过
- 像星光一样闪烁
  6分钟前 看过
- 白马过平川
  7分钟前 看过

1475332人看过 / 838381人想看

订阅小偷家族的评论:
feed: rss 2.0